/**
        qled - Copyright (C) 2006, 2007 Simeon Simeonov

 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2, or (at your option)
 any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software Foundation,
 Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.

**/


#ifndef GLWIDGET_H
#define GLWIDGET_H

#include <QGLWidget>


class GLWidget : public QGLWidget
{
  Q_OBJECT

private:

  int rangle; /* keeps the rotation angle */
  int hours, minutes, old_minutes, old_hours;

  unsigned int settings:3; /* 3-bit settings */

  QPoint old_pos; /* keeps track of the last mouse position */

  GLuint l_object, d_object; /* light object and dark object file decriptors */
  int x_rotation, y_rotation;

  static void getLedArray(int *array, int value, int size); /* copy the binary value of 'value' to 'array' with size 'size' */

  /* enable / disable settings - feature */
  void settingsEnable(unsigned int mask) { settings = settings | mask; }
  void settingsDisable(unsigned int mask) { settings = settings & (~mask); }

  void displayHelp(); /* display the help text */

  GLuint makeLObject() const; /* make light object */
  GLuint makeDObject() const; /* make dark object */
    
private slots:
void executeTicks();

protected:

    void initializeGL();
    void paintGL();
    void resizeGL(int width, int height);
    void keyPressEvent (QKeyEvent * event);
    void mousePressEvent(QMouseEvent *event);
    void mouseMoveEvent(QMouseEvent *event);
    void mouseDoubleClickEvent(QMouseEvent *event);

public:

    GLWidget(QWidget *parent = 0);
    ~GLWidget();

    QSize minimumSizeHint() const;
    QSize sizeHint() const;    

};

#endif
